"""Telegram message entity."""

import dataclasses
import datetime
import enum

# pylint: disable=invalid-name


class ChatType(enum.Enum):
    """Chat type."""

    PRIVATE = enum.auto()
    GROUP = enum.auto()
    SUPERGROUP = enum.auto()


@dataclasses.dataclass(frozen=True)
class User:
    """Telegram user or bot."""

    id: int
    is_bot: bool
    username: str


@dataclasses.dataclass(frozen=True)
class Chat:
    """Telegram chat."""

    id: int
    type: ChatType


@dataclasses.dataclass(frozen=True)
class Message:
    """Telegram message."""

    message_id: int
    message_from: User
    chat: Chat
    date: datetime.datetime
    text: str



"""Tokenize telegram messages."""

from typing import List

from tglex import message
from tglex import token


def tokenize(msg: message.Message) -> List[token.Token]:
    """Tokenize message."""
    return [token.Token(text=x) for x in msg.text.split()]



"""Setuptools script."""

import codecs

import setuptools

with codecs.open('README.md', encoding='utf-8') as readme:
    LONG_DESCRIPTION = readme.read()

setuptools.setup(
    name='tglex',
    version='0.1.2',
    author='Azat Kurbanov',
    author_email='cordalace@gmail.com',
    description='Lexical analysis base for telegram bots',
    long_description=LONG_DESCRIPTION,
    license='MIT',
    url='https://github.com/cordalace/tglex',
    packages=setuptools.find_packages(
        exclude=["*.tests", "*.tests.*", "tests.*", "tests"],
    ),
    entry_points={},
    package_data={
        'tglex': [],
    },
    zip_safe=True,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: Communications :: Chat',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing :: Linguistic',
        'Typing :: Typed',
    ],
)
